Trait random_access_storage::RandomAccess[][src]

pub trait RandomAccess {
    type Error;
    fn write(&mut self, offset: usize, data: &[u8]) -> Result<(), Self::Error>;
fn read(
        &mut self,
        offset: usize,
        length: usize
    ) -> Result<Vec<u8>, Self::Error>;
fn read_to_writer(
        &mut self,
        offset: usize,
        length: usize,
        buf: &mut impl Write
    ) -> Result<(), Self::Error>;
fn del(&mut self, offset: usize, length: usize) -> Result<(), Self::Error>; }

The RandomAccess trait allows for reading from and writing to a randomly accessible storage of bytes.

Associated Types

An error.

Required Methods

Write bytes at an offset to the backend.

Read a sequence of bytes at an offset from the backend.

Read a sequence of bytes at an offset from the backend.

Delete a sequence of bytes at an offset from the backend.

Implementors